@@ -6,6 +6,7 @@ from unittest import mock
 
 from faker import Faker
 from faker.providers.person.ar_AA import Provider as ArProvider
+from faker.providers.person.ar_DZ import Provider as ArDZProvider
 from faker.providers.person.az_AZ import Provider as AzAzProvider
 from faker.providers.person.cs_CZ import Provider as CsCZProvider
 from faker.providers.person.de_AT import Provider as DeAtProvider
@@ -23,6 +24,7 @@ from faker.providers.person.es_CO import Provider as EsCOProvider
 from faker.providers.person.et_EE import Provider as EtEEProvider
 from faker.providers.person.fi_FI import Provider as FiProvider
 from faker.providers.person.fr_BE import Provider as FrBEProvider
+from faker.providers.person.fr_DZ import Provider as FrDZProvider
 from faker.providers.person.ga_IE import Provider as GaIEProvider
 from faker.providers.person.gu_IN import Provider as GuINProvider
 from faker.providers.person.ha_NG import Provider as HaNgProvider
@@ -111,6 +113,52 @@ class TestAr(unittest.TestCase):
         assert name in ArProvider.last_names
 
 
+class TestArDZ(unittest.TestCase):
+
+    def setUp(self):
+        self.fake = Faker("ar_DZ")
+        self.provider = ArDZProvider
+        Faker.seed(0)
+
+    def test_general_first_name(self):
+        name = self.fake.first_name()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.first_names
+
+    def test_female_first_name(self):
+        name = self.fake.first_name_female()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.first_names
+        assert name in self.provider.first_names_female
+
+    def test_male_first_name(self):
+        name = self.fake.first_name_male()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.first_names
+        assert name in self.provider.first_names_male
+
+    def test_general_last_name(self):
+        name = self.fake.last_name()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.last_names
+
+    def test_female_last_name(self):
+        name = self.fake.last_name_female()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.last_names
+
+    def test_male_last_name(self):
+        name = self.fake.last_name_male()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.last_names
+
+
 class TestAzAz(unittest.TestCase):
     """Tests for az_AZ locale person provider"""
 
@@ -820,6 +868,52 @@ class TestFrBE(unittest.TestCase):
         assert name in self.provider.last_names
 
 
+class TestFrDZ(unittest.TestCase):
+
+    def setUp(self):
+        self.fake = Faker("fr_DZ")
+        self.provider = FrDZProvider
+        Faker.seed(0)
+
+    def test_general_first_name(self):
+        name = self.fake.first_name()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.first_names
+
+    def test_female_first_name(self):
+        name = self.fake.first_name_female()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.first_names
+        assert name in self.provider.first_names_female
+
+    def test_male_first_name(self):
+        name = self.fake.first_name_male()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.first_names
+        assert name in self.provider.first_names_male
+
+    def test_general_last_name(self):
+        name = self.fake.last_name()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.last_names
+
+    def test_female_last_name(self):
+        name = self.fake.last_name_female()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.last_names
+
+    def test_male_last_name(self):
+        name = self.fake.last_name_male()
+        assert name
+        self.assertIsInstance(name, str)
+        assert name in self.provider.last_names
+
+
 class TestGaIE(TestEnIE):
     """Tests person in the ga-IE locale"""
 
